@@ -250,55 +250,55 @@ def rq_save_stock_day_adj_fillna_pg(start_date='20190101'): #20050101
             print(e)
 
 
-def rq_save_swl_day_pg(start_date='2020-01-01'): #from 2015-01-04   
+def rq_save_swl_day_pg(start_date='2020-01-01'): #from 2015-01-04
+    table_name='swl_day'
     t = time.localtime(time.time())
     if int(time.strftime('%H%M%S',t))<210000:   #晚上9点之后在更新当天数据，以免不及时
         t = time.localtime(time.time()-3600*24)
         tS = time.strftime("%Y-%m-%d", t)
-    else:                
-        tS = time.strftime("%Y-%m-%d", t)    
+    else:
+        tS = time.strftime("%Y-%m-%d", t)
     end_date=tS
     print(end_date)
-    try: 
-        mes='SELECT DISTINCT trade_date FROM swl_day;'
+    try:
+        mes=f'select distinct trade_date FROM {table_name};'
+        #mes='SELECT DISTINCT trade_date FROM swl_day;'
         trade_data_pg = load_data_from_postgresql(mes).trade_date.tolist()
         #print(trade_data_pg[-3:])
-        #print(len(trade_data_pg))
-        #time.sleep(3)
-        #for i in range(len(trade_data_pg)):
-        #    print(i)
-        #    trade_data_pg[i]=trade_data_pg[i].strftime("%Y-%m-%d")
-        #    print(trade_data_pg[i])
-        trade_data_pg = list(map(lambda x: x.strftime('%Y-%m-%d'), trade_data_pg))
-        #print(len(trade_data_pg))
-        print(trade_data_pg[-1:])
-        #time.sleep(2)
+        for i in range(len(trade_data_pg)):
+            trade_data_pg[i]=trade_data_pg[i].strftime("%Y-%m-%d")
+            #trade_data_pg = list(map(lambda x: x.strftime('%Y-%m-%d'), trade_data_pg))
+            #print(len(trade_data_pg))
+            #print(trade_data_pg[-1:])
     except: #第一次运行
         trade_data_pg=list()
+        #print(trade_data_pg[-3:])
     if isinstance(start_date,int):
         start_date=rq_util_date_int2str(start_date)
     elif len(start_date)==8:
         start_date=start_date[0:4]+'-'+start_date[4:6]+'-'+start_date[6:8]
-    trade_date=rq_util_get_trade_range(start_date, end_date) 
-    trade_date2=list(set(trade_date).difference(set(trade_data_pg))) #差集 trade_date有, trade_data_pg没有
+        #print(start_date)
+    trade_date=rq_util_get_trade_range(start_date,end_date)
+    #print(trade_date)
+    trade_date2=list(set(trade_date).difference(set(trade_data_pg))) #差集 在trade_date 中 不在trade_data_pg
     trade_date2.sort()
-    print('^^^',trade_date2)
-    #time.sleep(5)
+    print(trade_date2)
+
     if len(trade_date2)==0:
-        rq_util_log_info('SWL day is up to date and does not need to be updated')
+        rq_util_log_info('swl day is up to date and does not need to be updated')
     for i in trade_date2:
         print(i)
         try:
-            t=time.time()        
-            df=fetch_swl_daily_tspro_adv(trade_date=i)   
-            #i=i[7:10].lower()+i[0:6]
-            save_data_to_postgresql('swl_day',df,'append')
+            t=time.time()
+            df=fetch_swl_daily_tspro_adv(trade_date=i)
+            save_data_to_postgresql(table_name, df, 'append')
+            t1=time.time()
+            tt = round((t1-t),4)
             time.sleep(1)
-            t1=time.time()   
-            rq_util_log_info('save '+i+'swl day success,take '+str(round(t1-t,2))+' S')        
+            rq_util_log_info(f'save {i} {table_name} success,take {tt}S')
         except Exception as e:
             print(e)
-   
+
 
 if __name__ == '__main__':          
     
