@@ -90,11 +90,10 @@ def swl_rs_valuation():
 
     for level in L:
         swl_rs_valuation_all(level)
-
     pass
 
 
-def write_stock_RS_OH_MA():
+def write_stock_RS_OH_MA_bak():
     st.text('相对强度 ')
     #table_name='stock_RS_OH_MA' if  current < start else 'stock_RS_OH_MA_new'
     table_name = 'stock_RS_OH_MA_new' 
@@ -143,7 +142,76 @@ def write_stock_RS_OH_MA():
     except Exception as e:
         print(e)    
 
+
+def write_stock_RS_OH_MA_new():
+    st.text('相对强度 ')
+    #table_name='stock_RS_OH_MA' if  current < start else 'stock_RS_OH_MA_new'
+    table_name = 'stock_RS_OH_MA_new' 
+    #st.write(table_name)
+    cols = ['name','code', 'close','pct_chg','OH',"OL","swl_L3", 'rs_10','rs_250']
+    cols2= ['name','code', 'close','pct_chg','ma20','ma250','rs_10','rs_250','OH',"OL","swl_L3"]
+    try:
+        #table_name='stock_RS_OH_MA_new'
+        #st.write(table_name)
+        st.text('相对强度 all')
+        df = pd.read_sql_table(table_name,conn)
+        st.write(df)
         
+        data = out_df_items(df)
+        df2 = data[0][cols]
+        df2 = df2.dropna(axis=0,how='any')
+        df2 = df2.sort_values(by='rs_10')
+        st.write(df2)
+       
+        
+        st.text('相对强度 all')
+        st.write('涨停', str(len(data[0][data[0].pct_chg > 9.90])),'只' , ',   ',\
+                    '跌停', str(len(data[0][data[0].pct_chg < -9.90])),'只' )
+        st.write(data[0], width=1200, height=600)
+        st.write('一年新高', str(len(df[df.OH >98])),'只' )
+        st.write(df2[(df2.OH > 98) ], width=1200, height=600) 
+        st.write('一年新低', str(len(df[df.OL <2])),'只' )
+        st.write(df2[df2.OL < 2], width=1200, height=600) 
+  
+        
+        data = out_df_items(df)
+        df2 = data[0][cols]
+        df2 = df2.dropna(axis=0,how='any')
+        df2 = df2.sort_values(by='rs_10')
+        st.write(df2)
+        
+        code = st.text_input('Input stock code:','600519')
+        df1 = data[0][cols2]
+        st.write(df1)
+        st.dataframe(df1[df1.code == code].T)
+        st.write(data[1], data[2])
+
+    except Exception as e:
+        print(e)    
+
+        
+def stock_select_PRS(table_name='stock_select_PRS'):
+    try:
+        df = pd.read_sql_table(table_name,conn)
+        df.rename(columns={'name':'display_name'},inplace=True)
+        #print(df)
+        data = out_df_items(df)
+        st.write('相对强度 top', str(len(df)), '只')
+        st.write(data[1], data[2])
+        st.dataframe(data[0], width=1200, height=600)
+    except Exception as e:
+        print(e)
+   
+
+def stock_fundmentals(): #TODO
+    #df = pd.read_sql_table('ROE_CF_SR_INC', conn)
+    code = st.text_input('Input stock code:','300146')
+    #code =st.multiselect('selects:',[1,2,3])
+    #st.write([code])
+    #st.text('股票基本面指标')
+    #st.write(df[df.code  == code].T)
+
+
 def stock_select_PRS(table_name='stock_select_PRS'):
     try:
         df = pd.read_sql_table(table_name,conn)
@@ -204,7 +272,8 @@ def other_info():
     st.write('myselect','http://quote.eastmoney.com/zixuan/?from=home')
     st.write("金十数据", "https://www.jin10.com/")
     st.write("商品价格","http://top.100ppi.com/zdb/detail-day---1.html")
-         
+        
+
 def main():
     selects = st.sidebar.selectbox(
     "Menu:",
@@ -215,15 +284,12 @@ def main():
         'stock_infomation',
         'other_info'))
     
-    if selects == 'stock_PRS':
-          write_stock_RS_OH_MA()   
-
     if selects == 'swl':
         swl_rs_valuation()
     if selects == "stock_PRS_top":
         stock_select_PRS()
     if selects == 'stock_PRS':
-        write_stock_RS_OH_MA()
+        write_stock_RS_OH_MA_new()
     if selects == 'stock_infomation':
         stock_infomation()
     if selects == 'other_info':
@@ -233,5 +299,4 @@ def main():
 if __name__ == "__main__":
     
     main()
-    pass
 
